import { __decorate, __metadata } from 'tslib';
import { EventEmitter, Input, Output, Component, ChangeDetectionStrategy, ViewChildren, forwardRef, QueryList, ChangeDetectorRef, ComponentFactoryResolver, ContentChildren, HostBinding, ViewChild, ViewContainerRef, NgModule } from '@angular/core';
import { FormGroup, ReactiveFormsModule } from '@angular/forms';
import { DynamicFormControlComponent, DynamicFormLayoutService, DynamicFormValidationService, DynamicCheckboxModel, DynamicTextAreaModel, DynamicSwitchModel, DynamicSelectModel, DynamicRadioGroupModel, DynamicInputModel, DynamicFormGroupComponent, DynamicFormGroupModel, DynamicFormControlContainerComponent, DynamicFormComponentService, DynamicFormRelationService, DynamicTemplateDirective, DynamicFormArrayGroupModel, DynamicFormControlModel, DYNAMIC_FORM_CONTROL_TYPE_TEXTAREA, DYNAMIC_FORM_CONTROL_TYPE_SWITCH, DYNAMIC_FORM_CONTROL_TYPE_SELECT, DYNAMIC_FORM_CONTROL_TYPE_RADIO_GROUP, DYNAMIC_FORM_CONTROL_TYPE_INPUT, DYNAMIC_FORM_CONTROL_TYPE_GROUP, DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX_GROUP, DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX, DYNAMIC_FORM_CONTROL_TYPE_ARRAY, DynamicFormArrayComponent, DynamicFormArrayModel, DynamicFormComponent, DynamicFormsCoreModule } from '@ng-dynamic-forms/core';
import { CommonModule } from '@angular/common';
import { TextMaskModule } from 'angular2-text-mask';

let DynamicFoundationCheckboxComponent = class DynamicFoundationCheckboxComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicFoundationCheckboxComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationCheckboxComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicFoundationCheckboxComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationCheckboxComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicCheckboxModel)
], DynamicFoundationCheckboxComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationCheckboxComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationCheckboxComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationCheckboxComponent.prototype, "focus", void 0);
DynamicFoundationCheckboxComponent = __decorate([
    Component({
        selector: "dynamic-foundation-checkbox",
        template: "<label [formGroup]=\"group\">\n\n    <input type=\"checkbox\"\n           [checked]=\"model.checked\"\n           [formControlName]=\"model.id\"\n           [id]=\"id\"\n           [indeterminate]=\"model.indeterminate\"\n           [name]=\"model.name\"\n           [ngClass]=\"getClass('element', 'control')\"\n           [required]=\"model.required\"\n           [tabindex]=\"model.tabIndex\"\n           [value]=\"model.value\"\n           (blur)=\"onBlur($event)\"\n           (change)=\"onChange($event)\"\n           (focus)=\"onFocus($event)\"/><span [ngClass]=\"[getClass('element', 'label'), getClass('grid', 'label')]\"\n                                            [innerHTML]=\"model.label\"></span></label>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicFoundationCheckboxComponent);

let DynamicFoundationTextAreaComponent = class DynamicFoundationTextAreaComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicFoundationTextAreaComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationTextAreaComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicFoundationTextAreaComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationTextAreaComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicTextAreaModel)
], DynamicFoundationTextAreaComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationTextAreaComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationTextAreaComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationTextAreaComponent.prototype, "focus", void 0);
DynamicFoundationTextAreaComponent = __decorate([
    Component({
        selector: "dynamic-foundation-textarea",
        template: "<ng-container [formGroup]=\"group\">\n\n    <textarea [class.is-invalid-input]=\"showErrorMessages\"\n              [cols]=\"model.cols\"\n              [formControlName]=\"model.id\"\n              [id]=\"id\"\n              [maxlength]=\"model.maxLength\"\n              [minlength]=\"model.minLength\"\n              [name]=\"model.name\"\n              [ngClass]=\"getClass('element', 'control')\"\n              [placeholder]=\"model.placeholder\"\n              [readonly]=\"model.readOnly\"\n              [required]=\"model.required\"\n              [rows]=\"model.rows\"\n              [spellcheck]=\"model.spellCheck\"\n              [tabindex]=\"model.tabIndex\"\n              [wrap]=\"model.wrap\"\n              (blur)=\"onBlur($event)\"\n              (change)=\"onChange($event)\"\n              (focus)=\"onFocus($event)\"></textarea>\n\n</ng-container>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicFoundationTextAreaComponent);

let DynamicFoundationSwitchComponent = class DynamicFoundationSwitchComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicFoundationSwitchComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationSwitchComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicFoundationSwitchComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationSwitchComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicSwitchModel)
], DynamicFoundationSwitchComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationSwitchComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationSwitchComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationSwitchComponent.prototype, "focus", void 0);
DynamicFoundationSwitchComponent = __decorate([
    Component({
        selector: "dynamic-foundation-switch",
        template: "<div [formGroup]=\"group\" class=\"switch\" [ngClass]=\"getClass('element', 'control')\">\n\n    <input type=\"checkbox\" class=\"switch-input\"\n           [checked]=\"model.checked\"\n           [formControlName]=\"model.id\"\n           [id]=\"id\"\n           [name]=\"model.name\"\n           [required]=\"model.required\"\n           [tabindex]=\"model.tabIndex\"\n           [value]=\"model.value\"\n           (blur)=\"onBlur($event)\"\n           (change)=\"onChange($event)\"\n           (focus)=\"onFocus($event)\"/>\n\n    <label class=\"switch-paddle\" [for]=\"id\">\n\n        <span class=\"switch-active\" aria-hidden=\"true\">{{ model.onLabel }}</span>\n        <span class=\"switch-inactive\" aria-hidden=\"true\">{{ model.offLabel }}</span>\n\n    </label>\n\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicFoundationSwitchComponent);

let DynamicFoundationSelectComponent = class DynamicFoundationSelectComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicFoundationSelectComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationSelectComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicFoundationSelectComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationSelectComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicSelectModel)
], DynamicFoundationSelectComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationSelectComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationSelectComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationSelectComponent.prototype, "focus", void 0);
DynamicFoundationSelectComponent = __decorate([
    Component({
        selector: "dynamic-foundation-select",
        template: "<ng-container [formGroup]=\"group\">\n\n    <select [compareWith]=\"model.compareWithFn\"\n            [formControlName]=\"model.id\"\n            [id]=\"id\"\n            [name]=\"model.name\"\n            [ngClass]=\"getClass('element', 'control')\"\n            [required]=\"model.required\"\n            [tabindex]=\"model.tabIndex\"\n            (blur)=\"onBlur($event)\"\n            (change)=\"onChange($event)\"\n            (focus)=\"onFocus($event)\">\n\n        <option *ngFor=\"let option of model.options$ | async\"\n                [disabled]=\"option.disabled\"\n                [ngValue]=\"option.value\">{{ option.label }}\n        </option>\n\n    </select>\n\n</ng-container>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicFoundationSelectComponent);

let DynamicFoundationRadioGroupComponent = class DynamicFoundationRadioGroupComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicFoundationRadioGroupComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationRadioGroupComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicFoundationRadioGroupComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationRadioGroupComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicRadioGroupModel)
], DynamicFoundationRadioGroupComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationRadioGroupComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationRadioGroupComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationRadioGroupComponent.prototype, "focus", void 0);
DynamicFoundationRadioGroupComponent = __decorate([
    Component({
        selector: "dynamic-foundation-radio-group",
        template: "<fieldset role=\"radiogroup\"\n          [formGroup]=\"group\"\n          [id]=\"id\"\n          [name]=\"model.name\"\n          [ngClass]=\"getClass('element', 'control')\"\n          [tabindex]=\"model.tabIndex\"\n          (change)=\"onChange($event)\">\n\n    <legend *ngIf=\"model.legend\" [innerHTML]=\"model.legend\"></legend>\n\n    <label *ngFor=\"let option of model.options$ | async\" [ngClass]=\"getClass('element', 'option')\">\n\n        <input type=\"radio\"\n               [formControlName]=\"model.id\"\n               [name]=\"model.name\"\n               [value]=\"option.value\"\n               (blur)=\"onBlur($event)\"\n               (focus)=\"onFocus($event)\"/><span [innerHTML]=\"option.label\"></span></label>\n\n</fieldset>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicFoundationRadioGroupComponent);

let DynamicFoundationInputComponent = class DynamicFoundationInputComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicFoundationInputComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationInputComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicFoundationInputComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationInputComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicInputModel)
], DynamicFoundationInputComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationInputComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationInputComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationInputComponent.prototype, "focus", void 0);
DynamicFoundationInputComponent = __decorate([
    Component({
        selector: "dynamic-foundation-input",
        template: "<div [formGroup]=\"group\" class=\"input-group\">\n\n    <span *ngIf=\"model.prefix\" class=\"input-group-label\" [innerHTML]=\"model.prefix\"></span>\n\n    <input class=\"input-group-field\"\n           [attr.accept]=\"model.accept\"\n           [attr.max]=\"model.max\"\n           [attr.min]=\"model.min\"\n           [attr.multiple]=\"model.multiple\"\n           [attr.step]=\"model.step\"\n           [autocomplete]=\"model.autoComplete\"\n           [autofocus]=\"model.autoFocus\"\n           [class.is-invalid-input]=\"showErrorMessages\"\n           [dynamicList]=\"model.listId\"\n           [formControlName]=\"model.id\"\n           [id]=\"id\"\n           [maxlength]=\"model.maxLength\"\n           [minlength]=\"model.minLength\"\n           [name]=\"model.name\"\n           [ngClass]=\"getClass('element', 'control')\"\n           [pattern]=\"model.pattern\"\n           [placeholder]=\"model.placeholder\"\n           [readonly]=\"model.readOnly\"\n           [required]=\"model.required\"\n           [spellcheck]=\"model.spellCheck\"\n           [tabindex]=\"model.tabIndex\"\n           [textMask]=\"{mask: (model.mask || false), showMask: model.mask && !(model.placeholder)}\"\n           [type]=\"model.inputType\"\n           (blur)=\"onBlur($event)\"\n           (change)=\"onChange($event)\"\n           (focus)=\"onFocus($event)\"/>\n\n    <span *ngIf=\"model.suffix\" class=\"input-group-label\" [innerHTML]=\"model.suffix\"></span>\n\n    <datalist *ngIf=\"model.hasList\" [id]=\"model.listId\">\n\n        <option *ngFor=\"let option of model.list$ | async\" [value]=\"option\">\n\n    </datalist>\n\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicFoundationInputComponent);

let DynamicFoundationFormGroupComponent = class DynamicFoundationFormGroupComponent extends DynamicFormGroupComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicFoundationFormGroupComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationFormGroupComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicFoundationFormGroupComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationFormGroupComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicFormGroupModel)
], DynamicFoundationFormGroupComponent.prototype, "model", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationFormGroupComponent.prototype, "templates", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationFormGroupComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationFormGroupComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationFormGroupComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationFormGroupComponent.prototype, "focus", void 0);
__decorate([
    ViewChildren(forwardRef(() => DynamicFoundationFormControlContainerComponent)),
    __metadata("design:type", QueryList)
], DynamicFoundationFormGroupComponent.prototype, "components", void 0);
DynamicFoundationFormGroupComponent = __decorate([
    Component({
        selector: "dynamic-foundation-form-group",
        template: "<ng-container [formGroup]=\"group\">\n\n    <fieldset [formGroupName]=\"model.id\"\n              [id]=\"id\"\n              [name]=\"model.name\"\n              [ngClass]=\"getClass('element', 'control')\">\n\n        <legend *ngIf=\"model.legend\" [innerHTML]=\"model.legend\"></legend>\n\n        <dynamic-foundation-form-control *ngFor=\"let _model of model.group\"\n                                         [group]=\"control\"\n                                         [hidden]=\"_model.hidden\"\n                                         [layout]=\"formLayout\"\n                                         [model]=\"_model\"\n                                         [templates]=\"templates\"\n                                         [hostClass]=\"[getClass('element','children'), getClass('grid','children')]\"\n                                         (blur)=\"onBlur($event)\"\n                                         (change)=\"onChange($event)\"\n                                         (focus)=\"onFocus($event)\"\n                                         (bsEvent)=\"onCustomEvent($event, null, true)\"></dynamic-foundation-form-control>\n    </fieldset>\n\n</ng-container>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicFoundationFormGroupComponent);

let DynamicFoundationFormControlContainerComponent = class DynamicFoundationFormControlContainerComponent extends DynamicFormControlContainerComponent {
    constructor(changeDetectorRef, componentFactoryResolver, layoutService, validationService, componentService, relationService) {
        super(changeDetectorRef, componentFactoryResolver, layoutService, validationService, componentService, relationService);
        this.changeDetectorRef = changeDetectorRef;
        this.componentFactoryResolver = componentFactoryResolver;
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.componentService = componentService;
        this.relationService = relationService;
        this.context = null;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
    get componentType() {
        return this.componentService.getCustomComponentType(this.model) || foundationUIFormControlMapFn(this.model);
    }
};
DynamicFoundationFormControlContainerComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ComponentFactoryResolver },
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService },
    { type: DynamicFormComponentService },
    { type: DynamicFormRelationService }
];
__decorate([
    ContentChildren(DynamicTemplateDirective),
    __metadata("design:type", QueryList)
], DynamicFoundationFormControlContainerComponent.prototype, "contentTemplateList", void 0);
__decorate([
    HostBinding("class"),
    __metadata("design:type", Object)
], DynamicFoundationFormControlContainerComponent.prototype, "klass", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicFormArrayGroupModel)
], DynamicFoundationFormControlContainerComponent.prototype, "context", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicFoundationFormControlContainerComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], DynamicFoundationFormControlContainerComponent.prototype, "hostClass", void 0);
__decorate([
    Input("templates"),
    __metadata("design:type", QueryList)
], DynamicFoundationFormControlContainerComponent.prototype, "inputTemplateList", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationFormControlContainerComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicFormControlModel)
], DynamicFoundationFormControlContainerComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationFormControlContainerComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationFormControlContainerComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationFormControlContainerComponent.prototype, "focus", void 0);
__decorate([
    ViewChild("componentViewContainer", { read: ViewContainerRef, static: true }),
    __metadata("design:type", ViewContainerRef)
], DynamicFoundationFormControlContainerComponent.prototype, "componentViewContainerRef", void 0);
DynamicFoundationFormControlContainerComponent = __decorate([
    Component({
        selector: "dynamic-foundation-form-control",
        template: "<div [formGroup]=\"group\"\n     [ngClass]=\"['ng-dynamic-forms-'+model.type.toLowerCase(), getClass('element', 'container'), getClass('grid', 'container')]\">\n\n    <div *ngIf=\"!isCheckbox && hasLabel\" [ngClass]=\"getClass('grid', 'label')\">\n\n        <label [class.is-invalid-label]=\"showErrorMessages\"\n               [for]=\"id\"\n               [innerHTML]=\"model.label\"\n               [ngClass]=\"getClass('element', 'label')\"></label>\n    </div>\n\n    <ng-container *ngTemplateOutlet=\"startTemplate?.templateRef; context: model\"></ng-container>\n\n    <div [ngClass]=\"getClass('grid', 'control')\">\n\n        <ng-container #componentViewContainer></ng-container>\n\n    </div>\n\n    <ul *ngIf=\"showErrorMessages\" [ngClass]=\"[getClass('element', 'errors'), getClass('grid', 'errors')]\">\n        <li *ngFor=\"let message of errorMessages\" class=\"form-error is-visible\">{{ message }}</li>\n    </ul>\n\n    <ng-container *ngTemplateOutlet=\"endTemplate?.templateRef; context: model\"></ng-container>\n\n    <ng-content></ng-content>\n\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [ChangeDetectorRef,
        ComponentFactoryResolver,
        DynamicFormLayoutService,
        DynamicFormValidationService,
        DynamicFormComponentService,
        DynamicFormRelationService])
], DynamicFoundationFormControlContainerComponent);
function foundationUIFormControlMapFn(model) {
    switch (model.type) {
        case DYNAMIC_FORM_CONTROL_TYPE_ARRAY:
            return DynamicFoundationFormArrayComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX:
            return DynamicFoundationCheckboxComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX_GROUP:
            return DynamicFoundationFormGroupComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_GROUP:
            return DynamicFoundationFormGroupComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_INPUT:
            return DynamicFoundationInputComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_RADIO_GROUP:
            return DynamicFoundationRadioGroupComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_SELECT:
            return DynamicFoundationSelectComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_SWITCH:
            return DynamicFoundationSwitchComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_TEXTAREA:
            return DynamicFoundationTextAreaComponent;
        default:
            return null;
    }
}

let DynamicFoundationFormArrayComponent = class DynamicFoundationFormArrayComponent extends DynamicFormArrayComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicFoundationFormArrayComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationFormArrayComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicFoundationFormArrayComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationFormArrayComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicFormArrayModel)
], DynamicFoundationFormArrayComponent.prototype, "model", void 0);
__decorate([
    Input(),
    __metadata("design:type", QueryList)
], DynamicFoundationFormArrayComponent.prototype, "templates", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationFormArrayComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationFormArrayComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationFormArrayComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationFormArrayComponent.prototype, "focus", void 0);
__decorate([
    ViewChildren(forwardRef(() => DynamicFoundationFormControlContainerComponent)),
    __metadata("design:type", QueryList)
], DynamicFoundationFormArrayComponent.prototype, "components", void 0);
DynamicFoundationFormArrayComponent = __decorate([
    Component({
        selector: "dynamic-foundation-form-array",
        template: "<ng-container [formGroup]=\"group\">\n\n    <div [formArrayName]=\"model.id\" [id]=\"id\" [ngClass]=\"getClass('element', 'control')\">\n\n        <div *ngFor=\"let groupModel of model.groups; let idx = index\" role=\"group\"\n             [formGroupName]=\"idx\" [ngClass]=\"[getClass('element', 'group'), getClass('grid', 'group')]\">\n\n            <ng-container *ngTemplateOutlet=\"startTemplate?.templateRef; context: groupModel\"></ng-container>\n\n            <dynamic-foundation-form-control *ngFor=\"let _model of groupModel.group\"\n                                             [context]=\"groupModel\"\n                                             [group]=\"array.at(idx)\"\n                                             [hidden]=\"_model.hidden\"\n                                             [layout]=\"formLayout\"\n                                             [model]=\"_model\"\n                                             [templates]=\"templates\"\n                                             [hostClass]=\"[getClass('element','children'), getClass('grid','children')]\"\n                                             (blur)=\"onBlur($event)\"\n                                             (change)=\"onChange($event)\"\n                                             (focus)=\"onFocus($event)\"\n                                             (bsEvent)=\"onCustomEvent($event, null, true)\"></dynamic-foundation-form-control>\n\n            <ng-container *ngTemplateOutlet=\"endTemplate?.templateRef; context: groupModel\"></ng-container>\n\n        </div>\n\n    </div>\n\n</ng-container>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicFoundationFormArrayComponent);

let DynamicFoundationFormComponent = class DynamicFoundationFormComponent extends DynamicFormComponent {
    constructor(changeDetectorRef, componentService) {
        super(changeDetectorRef, componentService);
        this.changeDetectorRef = changeDetectorRef;
        this.componentService = componentService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicFoundationFormComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DynamicFormComponentService }
];
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicFoundationFormComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], DynamicFoundationFormComponent.prototype, "model", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicFoundationFormComponent.prototype, "layout", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationFormComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationFormComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicFoundationFormComponent.prototype, "focus", void 0);
__decorate([
    ContentChildren(DynamicTemplateDirective),
    __metadata("design:type", QueryList)
], DynamicFoundationFormComponent.prototype, "templates", void 0);
__decorate([
    ViewChildren(DynamicFoundationFormControlContainerComponent),
    __metadata("design:type", QueryList)
], DynamicFoundationFormComponent.prototype, "components", void 0);
DynamicFoundationFormComponent = __decorate([
    Component({
        selector: "dynamic-foundation-form",
        template: "<dynamic-foundation-form-control *ngFor=\"let controlModel of model; trackBy: trackByFn\"\n                                 [group]=\"group\"\n                                 [hidden]=\"controlModel.hidden\"\n                                 [layout]=\"layout\"\n                                 [model]=\"controlModel\"\n                                 [templates]=\"templates\"\n                                 (blur)=\"onBlur($event)\"\n                                 (change)=\"onChange($event)\"\n                                 (focus)=\"onFocus($event)\"></dynamic-foundation-form-control>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [ChangeDetectorRef,
        DynamicFormComponentService])
], DynamicFoundationFormComponent);

let DynamicFormsFoundationUIModule = class DynamicFormsFoundationUIModule {
};
DynamicFormsFoundationUIModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            ReactiveFormsModule,
            TextMaskModule,
            DynamicFormsCoreModule
        ],
        declarations: [
            DynamicFoundationCheckboxComponent,
            DynamicFoundationFormArrayComponent,
            DynamicFoundationFormComponent,
            DynamicFoundationFormControlContainerComponent,
            DynamicFoundationFormGroupComponent,
            DynamicFoundationInputComponent,
            DynamicFoundationRadioGroupComponent,
            DynamicFoundationSelectComponent,
            DynamicFoundationSwitchComponent,
            DynamicFoundationTextAreaComponent
        ],
        entryComponents: [
            DynamicFoundationCheckboxComponent,
            DynamicFoundationFormArrayComponent,
            DynamicFoundationFormGroupComponent,
            DynamicFoundationInputComponent,
            DynamicFoundationRadioGroupComponent,
            DynamicFoundationSelectComponent,
            DynamicFoundationSwitchComponent,
            DynamicFoundationTextAreaComponent
        ],
        exports: [
            DynamicFormsCoreModule,
            DynamicFoundationCheckboxComponent,
            DynamicFoundationFormArrayComponent,
            DynamicFoundationFormComponent,
            DynamicFoundationFormControlContainerComponent,
            DynamicFoundationFormGroupComponent,
            DynamicFoundationInputComponent,
            DynamicFoundationRadioGroupComponent,
            DynamicFoundationSelectComponent,
            DynamicFoundationSwitchComponent,
            DynamicFoundationTextAreaComponent
        ]
    })
], DynamicFormsFoundationUIModule);

/**
 * Generated bundle index. Do not edit.
 */

export { DynamicFormsFoundationUIModule, DynamicFoundationCheckboxComponent, DynamicFoundationFormArrayComponent, DynamicFoundationFormComponent, DynamicFoundationFormControlContainerComponent, DynamicFoundationFormGroupComponent, DynamicFoundationInputComponent, DynamicFoundationRadioGroupComponent, DynamicFoundationSelectComponent, DynamicFoundationSwitchComponent, DynamicFoundationTextAreaComponent, foundationUIFormControlMapFn };
//# sourceMappingURL=ui-foundation.js.map
